]> sigrok.org Git - libsigrok.git/blobdiff - device.c
libsigrok: Rename open/close to opendev/closedev.
[libsigrok.git] / device.c
index 6e9a30086b610a590ac9c3190ff5698751758166..a1556aa4e37244cb57bdf97f7ec644771cc70b7a 100644 (file)
--- a/device.c
+++ b/device.c
@@ -65,8 +65,8 @@ void sr_device_close_all(void)
 
        while (devices) {
                device = devices->data;
-               if (device->plugin && device->plugin->close)
-                       device->plugin->close(device->plugin_index);
+               if (device->plugin && device->plugin->closedev)
+                       device->plugin->closedev(device->plugin_index);
                sr_device_destroy(device);
        }
 }
@@ -86,7 +86,11 @@ struct sr_device *sr_device_new(struct sr_device_plugin *plugin, int plugin_inde
        struct sr_device *device;
        int i;
 
-       device = g_malloc0(sizeof(struct sr_device));
+       if (!(device = g_try_malloc0(sizeof(struct sr_device)))) {
+               sr_err("dev: %s: device malloc failed", __func__);
+               return NULL;
+       }
+
        device->plugin = plugin;
        device->plugin_index = plugin_index;
        devices = g_slist_append(devices, device);
@@ -154,7 +158,13 @@ void sr_device_probe_add(struct sr_device *device, const char *name)
        int probenum;
 
        probenum = g_slist_length(device->probes) + 1;
-       p = g_malloc0(sizeof(struct sr_probe));
+
+       if (!(p = g_try_malloc0(sizeof(struct sr_probe)))) {
+               sr_err("dev: %s: p malloc failed", __func__);
+               // return SR_ERR_MALLOC;
+               return; /* FIXME: should return int. */
+       }
+
        p->index = probenum;
        p->enabled = TRUE;
        if (name) {
@@ -184,7 +194,7 @@ struct sr_probe *sr_device_probe_find(struct sr_device *device, int probenum)
        return found_probe;
 }
 
/* TODO: return SIGROK_ERR if probenum not found */
 void sr_device_probe_name(struct sr_device *device, int probenum,
                          const char *name)
 {
@@ -199,7 +209,7 @@ void sr_device_probe_name(struct sr_device *device, int probenum,
        p->name = g_strdup(name);
 }
 
/* TODO: return SIGROK_ERR if probenum not found */
 void sr_device_trigger_clear(struct sr_device *device)
 {
        struct sr_probe *p;
@@ -217,7 +227,7 @@ void sr_device_trigger_clear(struct sr_device *device)
        }
 }
 
/* TODO: return SIGROK_ERR if probenum not found */
 void sr_device_trigger_set(struct sr_device *device, int probenum,
                           const char *trigger)
 {
@@ -184,7 +194,7 @@ struct sr_probe *sr_device_probe_find(struct sr_device *device, int probenum)
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
+/* TODO: return SR_ERR if probenum not found */
 void sr_device_probe_name(struct sr_device *device, int probenum,
                          const char *name)
@@ -199,7 +209,7 @@ void sr_device_probe_name(struct sr_device *device, int probenum,
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
+/* TODO: return SR_ERR if probenum not found */
 void sr_device_trigger_clear(struct sr_device *device)
 {
@@ -217,7 +227,7 @@ void sr_device_trigger_clear(struct sr_device *device)
 }
 
-/* TODO: return SIGROK_ERR if probenum not found */
+/* TODO: return SR_ERR if probenum not found */
 void sr_device_trigger_set(struct sr_device *device, int probenum,
                           const char *trigger)